# Class: cloudinsight_agent::integrations::apache
#
# This class will install the necessary configuration for the apache integration
#
# Parameters:
#   $url:
#       The URL for apache status URL handled by mod-status.
#       Defaults to http://localhost/server-status?auto
#   $username:
#   $password:
#       If your service uses basic authentication, you can optionally
#       specify a username and password that will be used in the check.
#       Optional.
#   $tags
#       Optional array of tags
#
# Sample Usage:
#
# include 'cloudinsight_agent::integrations::apache'
#
# OR
#
# class { 'cloudinsight_agent::integrations::apache':
#   url      => 'http://example.com/server-status?auto',
#   username => 'status',
#   password => 'hunter1',
# }
#
class cloudinsight_agent::integrations::apache (
  $url       = 'http://localhost/server-status?auto',
  $username  = undef,
  $password  = undef,
  $tags      = []
) inherits cloudinsight_agent::params {

  validate_string($url)
  validate_array($tags)

  file { "${cloudinsight_agent::params::conf_dir}/apache.yaml":
    ensure  => file,
    owner   => $cloudinsight_agent::params::cloudinsight_user,
    group   => $cloudinsight_agent::params::cloudinsight_group,
    mode    => '0600',
    content => template('cloudinsight_agent/agent-conf.d/apache.yaml.erb'),
    require => Package[$cloudinsight_agent::params::package_name],
    notify  => Service[$cloudinsight_agent::params::service_name]
  }
}
