# Class: cloudinsight_agent::integrations::directory
#
# This class will install the necessary config to hook the directory check
#
# Parameters:
#   $directory
#       The directory to gather stats for
#   $name
#       The name used to tag the metrics (directory alias)
#   $pattern
#       The `fnmatch` pattern to use when reading the "directory"'s files. default "*"
#   $recursive
#       Boolean, when true the stats will recurse into directories
#
# Sample Usage:
#
#  class { 'cloudinsight_agent::integrations::directory' :
#      directory     => '/mnt/media',
#      name          => 'name,
#      pattern       => '*',
#      recursive     => true,
#  }
class cloudinsight_agent::integrations::directory (
  $directory = undef,
  $name      = '',
  $pattern   = '*',
  $recursive = false
) inherits cloudinsight_agent::params {

  if $directory == undef {
    fail('you must specify a directory path within the cloudinsight_agent::integrations::directory class')
  }

  file { "${cloudinsight_agent::params::conf_dir}/directory.yaml":
    ensure  => file,
    owner   => $cloudinsight_agent::params::cloudinsight_user,
    group   => $cloudinsight_agent::params::cloudinsight_group,
    mode    => '0600',
    content => template('cloudinsight_agent/agent-conf.d/directory.yaml.erb'),
    require => Package[$cloudinsight_agent::params::package_name],
    notify  => Service[$cloudinsight_agent::params::service_name]
  }
}
