# Class: cloudinsight_agent::integrations::docker
#
# This class will install the necessary configuration for the docker integration
#
# Parameters:
#   $new_tag_names:
#     Update docker new tags
#
#   $url:
#     The URL for docker API
#
#   $tags:
#     optional array of tags
#
# Sample Usage:
#
#   class { 'cloudinsight_agent::integrations::docker' :
#     new_tag_names => true,
#     url           => 'unix://var/run/docker.sock',
#   }
#
class cloudinsight_agent::integrations::docker(
  $new_tag_names = true,
  $url = 'unix://var/run/docker.sock',
  $tags = [],
) inherits cloudinsight_agent::params {

  file { "${cloudinsight_agent::params::conf_dir}/docker.yaml":
    ensure  => file,
    owner   => $cloudinsight_agent::params::cloudinsight_user,
    group   => $cloudinsight_agent::params::cloudinsight_group,
    mode    => '0644',
    content => template('cloudinsight_agent/agent-conf.d/docker.yaml.erb'),
    require => Package[$cloudinsight_agent::params::package_name],
    notify  => Service[$cloudinsight_agent::params::service_name]
  }
}
