# Class: cloudinsight_agent::integrations::mysql
#
# This class will install the necessary configuration for the mysql integration
#
# Parameters:
#   $host:
#       The host mysql is running on
#   $password
#       The mysql password for the cloudinsight user
#   $user
#       The mysql user for the cloudinsight user
#   $sock
#       Connect mysql via unix socket
#   $tags
#       Optional array of tags
#   $replication
#       replication option
#   $galera_cluster
#       galera cluster option
#
# Sample Usage:
#
#  class { 'cloudinsight_agent::integrations::mysql' :
#    host     => 'localhost',
#    password => 'some_pass',
#    user     => 'cloudinsight'
#  }
#
#
class cloudinsight_agent::integrations::mysql(
  $host = 'localhost',
  $password,
  $user = 'cloudinsight',
  $sock = undef,
  $tags = [],
  $replication = '0',
  $galera_cluster = '0'
) inherits cloudinsight_agent::params {

  validate_array($tags)

  file { "${cloudinsight_agent::params::conf_dir}/mysql.yaml":
    ensure  => file,
    owner   => $cloudinsight_agent::params::cloudinsight_user,
    group   => $cloudinsight_agent::params::cloudinsight_group,
    mode    => '0600',
    content => template('cloudinsight_agent/agent-conf.d/mysql.yaml.erb'),
    require => Package[$cloudinsight_agent::params::package_name],
    notify  => Service[$cloudinsight_agent::params::service_name],
  }
}
