# Class: cloudinsight_agent::integrations::varnish
#
# This class will install the necessary configuration for the varnish integration
#
# Parameters:
#   varnishstat
#       Path to the varnishstat binary
#
#   tags
#       cloudinsight-agent tags
#
# Sample usage:
#
# include 'cloudinsight_agent::integrations::varnish'
#
# class { 'cloudinsight_agent::integrations::varnish':
#   url      => '/usr/bin/varnishstat',
#   tags     => ['env:production'],
# }
#
class cloudinsight_agent::integrations::varnish (
  $varnishstat = '/usr/bin/varnishstat',
  $tags      = [],
) inherits cloudinsight_agent::params {

  file { "${cloudinsight_agent::params::conf_dir}/varnish.yaml":
    ensure  => file,
    owner   => $cloudinsight_agent::params::cloudinsight_user,
    group   => $cloudinsight_agent::params::cloudinsight_group,
    mode    => '0600',
    content => template('cloudinsight_agent/agent-conf.d/varnish.yaml.erb'),
    require => Package[$cloudinsight_agent::params::package_name],
    notify  => Service[$cloudinsight_agent::params::service_name]
  }
}
