# Class: cloudinsight_agent::redhat
#
# This class contains the cloudinsight-agent installation mechanism for Red Hat derivatives
#
# Parameters:
#   $baseurl:
#       Baseurl for the cloudinsight yum repo
#       Defaults to http://yum.oneapm.com/${::architecture}/
#
# Actions:
#
# Requires:
#
# Sample Usage:
#
class cloudinsight_agent::redhat(
  $baseurl = "http://yum.oneapm.com/${::architecture}/"
) {

  validate_string($baseurl)

  yumrepo {'cloudinsight-agent':
    enabled  => 1,
    gpgcheck => 0,
    descr    => 'OneAPM, Inc.',
    baseurl  => $baseurl,
  }

  package { 'cloudinsight-agent-base':
    ensure => absent,
    before => Package['cloudinsight-agent'],
  }

  package { 'cloudinsight-agent':
    ensure  => latest,
    require => Yumrepo['cloudinsight-agent'],
  }

  service { 'cloudinsight-agent':
    ensure    => $::cloudinsight_agent::service_ensure,
    enable    => $::cloudinsight_agent::service_enable,
    hasstatus => false,
    pattern   => 'cloudinsight-agent',
    require   => Package['cloudinsight-agent'],
  }

}
