# Class: cloudinsight_agent::reports
#
# This class configures the puppetmaster for reporting back to
# the cloudinsight service.
#
# Parameters:
#   $license_key:
#       Your Cloudinsight LICENSE Key. Please replace with your key value
#
# Actions:
#
# Requires:
#
# Sample Usage:
#
class cloudinsight_agent::reports(
  $license_key,
  $puppetmaster_user
) {

  include cloudinsight_agent::params
  $rubydev_package = $cloudinsight_agent::params::rubydev_package

  # check to make sure that you're not installing rubydev somewhere else
  if ! defined(Package[$rubydev_package]) {
    package {$rubydev_package:
      ensure => installed,
      before => Package['cloudinsight_api']
    }
  }

  if (! defined(Package['rubygems'])) {
    # Ensure rubygems is installed
    class { 'ruby':
      rubygems_update => false
    }
  }

  file { '/etc/cloudinsight-agent/cloudinsight-agent.yaml':
    ensure  => file,
    content => template('cloudinsight_agent/cloudinsight-agent.yaml.erb'),
    owner   => $puppetmaster_user,
    group   => 'root',
    mode    => '0640',
    require => File['/etc/cloudinsight-agent'],
  }

  package{'cloudinsight_api':
    ensure   => 'installed',
    provider => 'gem',
  }

}
