# Class: cloudinsight_agent::ubuntu
#
# This class contains the cloudinsight-agent installation mechanism for Ubuntu
#
# Parameters:
#
# Actions:
#
# Requires:
#
# Sample Usage:
#
class cloudinsight_agent::ubuntu(
  $apt_key = '54B043BC'
) {

  exec { 'cloudinsight_key':
    command => "/usr/bin/apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys ${apt_key}",
    unless  => "/usr/bin/apt-key list | grep ${apt_key} | grep expires",
    before  => File['/etc/apt/sources.list.d/cloudinsight-agent.list'],
  }

  file { '/etc/apt/sources.list.d/cloudinsight-agent.list':
    source => 'puppet:///modules/cloudinsight_agent/cloudinsight-agent.list',
    owner  => 'root',
    group  => 'root',
    notify => Exec['cloudinsight_apt-get_update'],
  }

  exec { 'cloudinsight_apt-get_update':
    command     => '/usr/bin/apt-get update',
    refreshonly => true,
  }

  package { 'cloudinsight-agent-base':
    ensure => absent,
    before => Package['cloudinsight-agent'],
  }

  package { 'cloudinsight-agent':
    ensure  => latest,
    require => [File['/etc/apt/sources.list.d/cloudinsight-agent.list'],
                Exec['cloudinsight_apt-get_update']],
  }

  service { 'cloudinsight-agent':
    ensure    => $::cloudinsight_agent::service_ensure,
    enable    => $::cloudinsight_agent::service_enable,
    hasstatus => false,
    pattern   => 'cloudinsight-agent',
    require   => Package['cloudinsight-agent'],
  }

}
