require 'spec_helper'

describe 'cloudinsight_agent' do
  context 'unsupported operating system' do
    describe 'cloudinsight_agent class without any parameters on Solaris/Nexenta' do
      let(:facts) do
        {
          osfamily:         'Solaris',
          operatingsystem:  'Nexenta'
        }
      end

      it do
        expect {
          should contain_package('module')
        }.to raise_error(Puppet::Error, /Unsupported operatingsystem: Nexenta/)
      end
    end
  end

  # Test all supported OSes
  context 'all supported operating systems' do
    ALL_OS.each do |operatingsystem|
      describe "cloudinsight_agent class common actions on #{operatingsystem}" do
        let(:params) { { puppet_run_reports: true } }
        let(:facts) do
          {
            operatingsystem: operatingsystem,
            osfamily: DEBIAN_OS.include?(operatingsystem) ? 'debian' : 'redhat'
          }
        end

        it { should compile.with_all_deps }

        it { should contain_class('cloudinsight_agent') }

        describe 'cloudinsight_agent imports the default params' do
          it { should contain_class('cloudinsight_agent::params') }
        end

        it { should contain_file('/etc/cloudinsight-agent') }
        it { should contain_file('/etc/cloudinsight-agent/cloudinsight-agent.conf') }

        it { should contain_class('cloudinsight_agent::reports') }

        if DEBIAN_OS.include?(operatingsystem)
          it { should contain_class('cloudinsight_agent::ubuntu') }
        elsif REDHAT_OS.include?(operatingsystem)
          it { should contain_class('cloudinsight_agent::redhat') }
        end
      end
    end
  end
end
